User prompt
Fix collision bug
User prompt
Make projectile collision logic use projectile hitbox
User prompt
Fix bugs
User prompt
Make projectile hitbox 2x2 but sprite size 100x100
User prompt
Use the original scale of the enemy projectile sprite but keep the hitbox 2x2
User prompt
Enemies still aren’t firing
User prompt
Please fix it
User prompt
Enemy projectiles have a 2x2 pixel hit box
User prompt
Look for bugs
User prompt
Add A player life bar to the bottom of the screen
User prompt
Enemies fire far fewer projectiles
User prompt
The player has 10 hit points
User prompt
Enemies have 3 hit points
User prompt
Enemies move dynamically trying to dodge the players projectiles
User prompt
Check for bugs in the code
User prompt
Add enemies that appear in waves from the top of the screen, firing slow moving projectiles that damage the player
User prompt
Treat citytiles as a 2x2 tile set
User prompt
Use a tile size of 804
User prompt
Use a tile size of 402
User prompt
Set tiles to 398x398
User prompt
Update to reflect new citytiles size
User prompt
Citytiles should fill the screen horizontally and vertically
User prompt
Repeat citytiles to fill the screen
User prompt
Tile citytiles asset as a bottom layer with a 0.1 move speed
User prompt
Cloud sprites are mirrored 50% of the time
/**** * Classes ****/ // Bullet class var Bullet = Container.expand(function () { var self = Container.call(this); // Attach the bullet sprite var bulletSprite = self.attachAsset('bullet', { anchorX: 0.5, anchorY: 0.5 }); // Set bullet speed self.speed = -10; // This is automatically called every game tick, if the bullet is attached! self.update = function () { self.y += self.speed; // Destroy the bullet if it goes off the screen if (self.y < -self.height) { self.destroy(); } }; }); // CityTiles class var CityTiles = Container.expand(function () { var self = Container.call(this); // Attach the city tiles sprite var cityTilesSprite = self.attachAsset('CityTiles', { anchorX: 0.5, anchorY: 0.5, scaleX: 2, scaleY: 2 }); // Set city tiles speed self.speed = 0.1; // This is automatically called every game tick, if the city tiles are attached! self.update = function () { self.y += self.speed; // Reset the position if the city tiles go off the screen if (self.y > 2732 + self.height / 2) { self.y = -self.height / 2; } }; }); // Cloud class var Cloud = Container.expand(function () { var self = Container.call(this); // Randomly assign cloud asset var cloudAssets = ['cloud1', 'cloud2', 'cloud3', 'cloud4', 'cloud5']; var randomCloud = cloudAssets.splice(Math.floor(Math.random() * cloudAssets.length), 1)[0]; var scale = Math.random() * 0.5 + 0.5; // Mirror cloud sprites 50% of the time var flipX = Math.random() > 0.5 ? -1 : 1; var cloudSprite = self.attachAsset(randomCloud, { anchorX: 0.5, anchorY: 0.5, scaleX: scale * flipX, scaleY: scale }); // Set cloud sprite to be 70% transparent cloudSprite.alpha = 0.3; // Set cloud speed self.speed = Math.random() * 3 + 2; // This is automatically called every game tick, if the cloud is attached! self.update = function () { self.y += self.speed * (1 + self.x / 2048 * 0.5); // Remove the cloud if it goes off the screen if (self.y > 2732 + self.height / 2) { // Remove the cloud from the clouds array var index = clouds.indexOf(self); if (index > -1) { clouds.splice(index, 1); cloudAssets.push(randomCloud); // Add the cloud back to the cloudAssets array } // Destroy the cloud self.destroy(); } }; }); // Player's vehicle class var PlayerVehicle = Container.expand(function () { var self = Container.call(this); // Attach the player's vehicle sprite var vehicleSprite = self.attachAsset('playerVehicle', { anchorX: 0.5, anchorY: 0.5, scaleX: 2, scaleY: 2 }); // This is automatically called every game tick, if the player's vehicle is attached! self.update = function () { // Fire a bullet every 30 ticks if (LK.ticks % 30 == 0) { var bullet = new Bullet(); bullet.x = self.x; bullet.y = self.y - self.height / 2 - bullet.height / 2; game.addChild(bullet); } }; // Add touch event handlers to the player's vehicle to enable dragging self.down = function (x, y, obj) { // Store the initial touch position self.initialTouchPosition = { x: x, y: y }; // Store the initial position of the player's vehicle self.initialPosition = { x: self.x, y: self.y }; }; self.move = function (x, y, obj) { // Update the position of the player's vehicle relative to the speed and direction at which the player moves their finger self.x = self.initialPosition.x + (x - self.initialTouchPosition.x); self.y = self.initialPosition.y + (y - self.initialTouchPosition.y); }; self.up = function (x, y, obj) { // Reset the initial touch position and the initial position of the player's vehicle self.initialTouchPosition = null; self.initialPosition = null; }; }); /**** * Initialize Game ****/ // Add player's vehicle to the game var game = new LK.Game({ backgroundColor: 0x000000 }); /**** * Game Code ****/ // Add CityTiles to the game and repeat to fill the screen horizontally var cityTilesArray = []; for (var i = 0; i < Math.ceil(2048 / 400) + 1; i++) { // 400 is the new width of a single CityTile for (var j = 0; j < Math.ceil(2732 / 400) + 1; j++) { // 400 is the new height of a single CityTile var cityTile = game.addChild(new CityTiles()); cityTile.x = i * 400; // Position each tile next to the previous one horizontally cityTile.y = j * 400; // Position each tile next to the previous one vertically cityTilesArray.push(cityTile); } } // Add player's vehicle to the game var playerVehicle = game.addChild(new PlayerVehicle()); playerVehicle.x = 2048 / 2; playerVehicle.y = 2732 - playerVehicle.height / 2; var dragNode = null; game.down = function (x, y, obj) { dragNode = playerVehicle; dragNode.initialTouchPosition = { x: x, y: y }; dragNode.initialPosition = { x: playerVehicle.x, y: playerVehicle.y }; }; game.move = function (x, y, obj) { if (dragNode) { var newX = dragNode.initialPosition.x + (x - dragNode.initialTouchPosition.x); var newY = dragNode.initialPosition.y + (y - dragNode.initialTouchPosition.y); // Limit player vehicle movement to within the screen newX = Math.max(Math.min(newX, 2048 - dragNode.width / 2), dragNode.width / 2); newY = Math.max(Math.min(newY, 2732 - dragNode.height / 2), dragNode.height / 2); dragNode.x = newX; dragNode.y = newY; } }; game.up = function (x, y, obj) { if (dragNode) { dragNode = null; } }; // Create an array to store the clouds var clouds = []; // Create a timer to add clouds at random intervals between 1 and 5 seconds var cloudTimer = LK.setInterval(function () { // Check if there are less than 4 clouds on screen if (clouds.length < 4) { var cloud = game.addChild(new Cloud()); cloud.y = -cloud.height; cloud.x = Math.random() * 2048; // Add the new cloud to the clouds array clouds.push(cloud); } }, Math.random() * 4000 + 1000);
===================================================================
--- original.js
+++ change.js
@@ -133,15 +133,15 @@
* Game Code
****/
// Add CityTiles to the game and repeat to fill the screen horizontally
var cityTilesArray = [];
-for (var i = 0; i < Math.ceil(2048 / 200) + 1; i++) {
- // 200 is the width of a single CityTile
- for (var j = 0; j < Math.ceil(2732 / 195.31) + 1; j++) {
- // 195.31 is the height of a single CityTile
+for (var i = 0; i < Math.ceil(2048 / 400) + 1; i++) {
+ // 400 is the new width of a single CityTile
+ for (var j = 0; j < Math.ceil(2732 / 400) + 1; j++) {
+ // 400 is the new height of a single CityTile
var cityTile = game.addChild(new CityTiles());
- cityTile.x = i * 200; // Position each tile next to the previous one horizontally
- cityTile.y = j * 195.31; // Position each tile next to the previous one vertically
+ cityTile.x = i * 400; // Position each tile next to the previous one horizontally
+ cityTile.y = j * 400; // Position each tile next to the previous one vertically
cityTilesArray.push(cityTile);
}
}
// Add player's vehicle to the game
Neon cyberpunk flying car. Single Game Texture. Blank background. High contrast. No shadows. Top-down
Fluffy cloud viewed from the top. Single Game Sprite Texture. No background.
This type of cloud but in a fine mist
One single Fluffy cloud viewed from the top. Single Game Sprite. No background. No shadow
Mini rocket projectile from a video game. No background.
Terminator style 2D enemy ship. Facing dead south. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows
Circular ball projectile from a video game. No background.
Make it look like night time